"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dispatcher = void 0;
const tsyringe_1 = require("tsyringe");
const AriesFrameworkError_1 = require("../error/AriesFrameworkError");
const MessageSender_1 = require("./MessageSender");
const TransportService_1 = require("./TransportService");
let Dispatcher = class Dispatcher {
    constructor(messageSender, transportService) {
        this.handlers = [];
        this.messageSender = messageSender;
        this.transportService = transportService;
    }
    registerHandler(handler) {
        this.handlers.push(handler);
    }
    async dispatch(messageContext) {
        const message = messageContext.message;
        const handler = this.getHandlerForType(message.type);
        if (!handler) {
            throw new AriesFrameworkError_1.AriesFrameworkError(`No handler for message type "${message.type}" found`);
        }
        const outboundMessage = await handler.handle(messageContext);
        if (outboundMessage) {
            await this.messageSender.sendMessage(outboundMessage);
        }
    }
    getHandlerForType(messageType) {
        for (const handler of this.handlers) {
            for (const MessageClass of handler.supportedMessages) {
                if (MessageClass.type === messageType)
                    return handler;
            }
        }
    }
    getMessageClassForType(messageType) {
        for (const handler of this.handlers) {
            for (const MessageClass of handler.supportedMessages) {
                if (MessageClass.type === messageType)
                    return MessageClass;
            }
        }
    }
};
Dispatcher = __decorate([
    tsyringe_1.scoped(tsyringe_1.Lifecycle.ContainerScoped),
    __metadata("design:paramtypes", [MessageSender_1.MessageSender, TransportService_1.TransportService])
], Dispatcher);
exports.Dispatcher = Dispatcher;
//# sourceMappingURL=Dispatcher.js.map